#
# spec file for package python-xattr
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-xattr
Version:        0.10.1
Release:        2.7
Summary:        Python wrapper for extended filesystem attributes
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/xattr/xattr
Source:         https://files.pythonhosted.org/packages/source/x/xattr/xattr-%{version}.tar.gz
BuildRequires:  %{python_module cffi}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cffi >= 1.11
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun):update-alternatives
%ifpython2
Provides:       pyxattr = %{version}
Obsoletes:      pyxattr < %{version}
%endif
%python_subpackages

%description
Extended attributes extend the basic attributes of files and directories
in the file system.  They are stored as name:data pairs associated with
file system objects (files, directories, symlinks, etc).

Extended attributes are currently only available on Darwin 8.0+ (Mac OS X 10.4)
and Linux 2.6+. Experimental support is included for Solaris and FreeBSD.

%prep
%setup -q -n xattr-%{version}
sed -i "/#\!\/usr\/bin\/env python/d" xattr/tool.py # Fix executable-bit rpmlint warning

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%python_clone -a %{buildroot}%{_bindir}/xattr

%check
export LC_ALL=en_US.utf-8
%pyunittest discover -v

%post
%python_install_alternative xattr

%postun
%python_uninstall_alternative xattr

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%python_alternative %{_bindir}/xattr
%{python_sitearch}/xattr
%{python_sitearch}/xattr-*egg-info

%changelog
* Sun Jul  2 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Dec  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v0.10.1
  * Update github actions
  * https://github.com/xattr/xattr/issues/112
  * Updated README to add reference to osxmetadata
  * https://github.com/xattr/xattr/pull/110
* Sat Oct 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.10.0
  * Remove exec flag from tool.py
  https://github.com/xattr/xattr/pull/106
  * Update the documentation to mention
  the attr package and its getfattr and
  setfattr tools
  https://github.com/xattr/xattr/pull/103
* Mon Jan  3 2022 Dirk Müller <dmueller@suse.com>
- update to 0.9.9:
  * Fix regression in xattr console script
  * Add -c clear option
  * Add note about Linux namespace requirement
* Mon Nov 29 2021 Dirk Müller <dmueller@suse.com>
- update to 0.9.8:
  * Update build to use Github Actions
  * Various dump related fixes
  * Fix classifiers list
* Wed Mar 18 2020 Dirk Mueller <dmueller@suse.com>
- add setuptools dependency (bsc#1161208)
* Thu Feb  6 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.9.7
  * Fix xattr().update() in Python 3
* Fri Mar 22 2019 Dirk Mueller <dmueller@suse.com>
- fix tests run failing on older distributions due to incorrect locale
* Fri Mar  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.9.6:
  * Fix release build by including *.[ch] in Manifest.in
  * Extract inline C code for syntax highlighting and easier maintenance
    https://github.com/xattr/xattr/pull/75
  * Fix Travis build
    https://github.com/xattr/xattr/pull/74
  * Always include sys/types.h (musl compatibility)
    https://github.com/xattr/xattr/pull/73
- Enable tests
* Thu Jul 12 2018 ecsos@opensuse.org
- update to 0.9.3:
  * Do not attempt to use surrogateescape unless it is available
    https://github.com/xattr/xattr/issues/59
* Thu Feb 22 2018 rjschwei@suse.com
- Relax version constraint for cffi requirement
* Wed Aug 30 2017 tbechtold@suse.com
- update to 0.9.2:
  * Fix BSD issue w/ lsattr and long attrs
    https://github.com/xattr/xattr/pull/57
  * Remove unreachable code
    https://github.com/xattr/xattr/pull/56
  * Allow (Python 2) long for fd
    https://github.com/xattr/xattr/pull/51
  * Fix Python 3 bytes handling in xattr.tool
    https://github.com/xattr/xattr/pull/50
  * Use cffi 1.X features to build native module for faster import
    https://github.com/xattr/xattr/pull/47
  * NOTE: Version 0.9.0 is the same, was momentarily uploaded with
    incomplete CHANGES.txt
- use pypi for Source url
- convert to singlespec
- require the cffi version it was built against
* Fri May 26 2017 ngompa13@gmail.com
- Properly add python-cffi as a runtime requirement
* Wed Jun  1 2016 tbechtold@suse.com
- update to 0.8.0:
  * Use os.fsencode where available to better handle filesystem quirks related
    to surrogates
  * Options bugfix and compatibility module for pyxattr API
  * Added xattr/tests/*.py to MANIFEST.in
* Sun Oct 18 2015 ecsos@opensuse.org
- update to 0.7.8
  * Added MANIFEST.in to ensure that the .txt files are included
    https://github.com/xattr/xattr/issues/40
- update to 0.7.7
  * Fixed FreeBSD build
    https://github.com/xattr/xattr/pull/32
- update to 0.7.6
  * Fixed Solaris & Solaris Studio support and Python 2.6
    compatibility
    https://github.com/xattr/xattr/pull/29
* Wed Sep 30 2015 dmueller@suse.com
- require the cffi version it was built against to avoid (bsc#948198)
* Tue Sep 16 2014 tbechtold@suse.com
- update to version 0.7.5:
  * Improved error message when str/unicode is passed where bytes is
    required
  * Improved Python 3 compatibility
  * Added some unicode-specific tests
* Thu Aug  8 2013 dmueller@suse.com
- update to 0.7.2:
  * rewritten to use cffi
  * Add Python 3.x support
  * Fix various unicode related issues
* Fri Mar 15 2013 speilicke@suse.com
- Add provides/obsoletes for pyxattr which just got deleted
- Some minor cleanup
* Fri Jun 22 2012 os-dev@jacraig.com
- Update to 0.6.4:
  * Updated README.txt to match setup.py description
  * Bug fixes for Solaris port
- Changes from 0.6.3:
  * Fix tests for Linux, allow xattr on symlinks
- Update URL as changed in setup.py
* Fri Nov 25 2011 cfarrell@suse.com
- license update: MIT
  SPDX format (http://www.spdx.org/licenses)
* Fri Sep 23 2011 saschpe@suse.de
- Update to version 0.6.2:
  * Bug fix in Solaris support
* Tue May 31 2011 saschpe@suse.de
- Spec file cleanup:
  * Regenerated with py2pack to fix completely broken mess
  * Add changes file
  * Fixed executable-bit rpmlint warning
